<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Patient;
use App\Sinedria;
use App\Reminder;
use App\WaitingList;
use App\Katigories;
use PDF;
use DataTables;
use Illuminate\Support\Facades\File;
use Carbon\Carbon;
use DateTime;


class PatientController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth');
    }


    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
//        $patients = Patient::all();
		return view('patients.index');    

    }

public function getData()
{

    $patient  = Patient::select('id', 'lastname', 'firstname', 'email', 'mobile', 'birthdate', 'comments', 'parapompi');


    return DataTables::of($patient)
			->addColumn('sinedries', function($patient){
             return $patient->patientSinedria()->count();
            })
            ->addColumn('actions', function($patient){
				$html = '<a href="patients/show/'.$patient->id.'" class="btn btn-primary btn-xs"> <i class="fa fa-search"></i></a>
								 <a href="patients/edit/'.$patient->id.'" class="btn btn-primary btn-xs"> <i class="fa fa-pencil"></i></a>
								 <a href="patients/addWaiting/'.$patient->id.'" class="btn btn-primary btn-xs"> <i class="fa fa-calendar"></i></a>
								 <button class="btn btn-danger btn-s btn-flat btn-delete delete-table btn-xs" value="'.$patient->id.'"><i class="fa fa-trash"></i></button>';
			return $html;
			}
			)
			->editColumn('birthdate', function ($patient) {
				$ymd = DateTime::createFromFormat('d/m/Y', $patient->birthdate)->format('Y-m-d');
				if ($ymd>'1900-1-1') {
		            return $patient->birthdate; //$patient->birthdate->age;
				} else {return '';}
//			   return [
//				  'display' => e(
//						$patient->birthdate->format('d/m/Y')
//				  ),
//				  'sdate' => $patient->birthdate
//			   ];
			})
			->escapeColumns([])
            ->make(true);        

}



    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        
		$listHistory = Katigories::where('id_katigoria', 100)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listHistoryDrug = Katigories::where('id_katigoria', 101)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listtameio = Katigories::where('id_katigoria', 103)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listorigin = Katigories::where('id_katigoria', 104)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listsmoking = Katigories::where('id_katigoria', 105)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listeth = Katigories::where('id_katigoria', 106)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listname = Katigories::where('id_katigoria', 107)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listcity = Katigories::where('id_katigoria', 108)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listgp = Katigories::where('id_katigoria', 109)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listparapompi = Katigories::where('id_katigoria', 110)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');

		return view('patients.create', compact('listHistory', 'listHistoryDrug', 'listtameio', 'listorigin', 'listsmoking', 'listeth', 'listname', 'listcity', 'listgp', 'listparapompi'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        
		$patient = $request->all();        	
		if (!$request->birthdate) {$patient['birthdate'] = '1900-01-01';}
		$id = Patient::create($patient)->id;
		if (!is_null($patient['tameio'])) {$firstname = Katigories::firstOrCreate(['onomasia' => $patient['tameio']], ['id_katigoria'=>103]);} 
		if (!is_null($patient['origin'])) {$firstname = Katigories::firstOrCreate(['onomasia' => $patient['origin']], ['id_katigoria'=>104]);} 
		if (!is_null($patient['smoking'])) {$firstname = Katigories::firstOrCreate(['onomasia' => $patient['smoking']], ['id_katigoria'=>105]);} 
		if (!is_null($patient['eth'])) {$firstname = Katigories::firstOrCreate(['onomasia' => $patient['eth']], ['id_katigoria'=>106]);} 
		if (!is_null($patient['firstname'])) {$firstname = Katigories::firstOrCreate(['onomasia' => $patient['firstname']], ['id_katigoria'=>107]);} 
		if (!is_null($patient['city'])) {$firstname = Katigories::firstOrCreate(['onomasia' => $patient['city']], ['id_katigoria'=>108]);} 
		if (!is_null($patient['gp'])) {$firstname = Katigories::firstOrCreate(['onomasia' => $patient['gp']], ['id_katigoria'=>109]);} 
		if (!is_null($patient['parapompi'])) {$firstname = Katigories::firstOrCreate(['onomasia' => $patient['parapompi']], ['id_katigoria'=>110]);} 
		return redirect('patients/show/'.$id);    
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
			$patient = Patient::find($id);
			$sinedries = Sinedria::where('patient_id', $id)->orderby('sinedriadate', 'desc')->get();
			$reminders = Patient::find($id)->patientReminder;
			return view('patients.show', compact('patient', 'sinedries', 'reminders')); 
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $patient = Patient::find($id);

		$listHistory = Katigories::where('id_katigoria', 100)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listHistoryDrug = Katigories::where('id_katigoria', 101)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');

		return view('patients.edit', compact('patient', 'listHistory', 'listHistoryDrug')); 
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $patientUpdate = $request->all();
		$patient = Patient::find($id);
		$patient->update($patientUpdate);
  	    return redirect('patients/show/'.$id); 
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $patient = Patient::find($id)->delete();
		return redirect('patients');
    }


    public function printEmptyForm($id)
    {

        $patient = Patient::find($id);  
		$max = Sinedria::where('patient_id', $id)->max('id');
		$sinedria = Sinedria::find($max);

		$pdf = PDF::loadView('patients.emptyForm', compact('patient', 'sinedria'));
		$pdf->setPaper('A4', 'portrait');
//		return $pdf->stream("filename.pdf", array("Attachment" => false));
//		return $pdf->download('emptyForm-'.$patient->lastname.'.pdf');	

		$match_files = File::glob('document*');
		if($match_files !== false) {
			foreach($match_files as $file) {
			if(file_exists($file))
			File::delete($file);
			}
		}
		$output = $pdf->output();
		$newfile = 'document'.strval(rand(0, 9999999)).'.pdf';
		file_put_contents($newfile, $output);
		echo $newfile;
		
    }



    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */

    public function detailSinedria($id)
    {

			$patient = Patient::find($id);
//			if ($sinedria_id == -1)  {
//				$max = Sinedria::where('patient_id', $id)->max('id');
//				$sinedria = Sinedria::find($max);
//			} else {
//				$sinedria = Sinedria::find($sinedria_id);
//			}


//			\Illuminate\Pagination\Paginator::currentPageResolver(function() use ($currentPage) { return $currentPage; });

			$sinedries = Sinedria::where('patient_id', $id)->orderby('sinedriadate', 'desc')->paginate(1);

			return view('patients.detailSinedria', compact('patient', 'sinedries')); 
    }


    public function createSinedria($id)
    {
        $patient = Patient::find($id);
		$listpresenting_complaint = Katigories::where('id_katigoria', 201) //�� listxxxx ������� �� autocomplete, ��� �� xxxxlist ������� select 
			->orderBy('onomasia')->pluck('onomasia', 'onomasia'); 
		$listclinical_endoscopy = Katigories::where('id_katigoria', 208)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listclinical_neurotology = Katigories::where('id_katigoria', 212)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listclinical_neck = Katigories::where('id_katigoria', 209)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listdiagnosis = Katigories::where('id_katigoria', 202)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listtreatment = Katigories::where('id_katigoria', 203)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listrecipe = Katigories::where('id_katigoria', 220)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$rinneList = Katigories::where('id_katigoria', 204)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$weberList = Katigories::where('id_katigoria', 205)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$tympList = Katigories::where('id_katigoria', 206)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$tonsilList = Katigories::where('id_katigoria', 207)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$malapantiList = Katigories::where('id_katigoria', 210)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$evidenceList = Katigories::where('id_katigoria', 221)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$priorityList = Katigories::where('id_katigoria', 200)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$check_surgeryList = Katigories::where('id_katigoria', 215)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$stopBangList = Katigories::where('id_katigoria', 222)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$mullerglossaList = Katigories::where('id_katigoria', 223)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');	
		$mulleryperoaList = Katigories::where('id_katigoria', 224)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');	

		$listclinical_pta = Katigories::where('id_katigoria', 213) //gia datalist
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listclinical_oral_cavity = Katigories::where('id_katigoria', 214) 
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');	
		$listclinical_otoscopy = Katigories::where('id_katigoria', 211)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');			

		$lastsinedria = Patient::find($id)->patientSinedria()->latest('sinedriadate')->first();
//		$lastsinedria = Patient::find($id)->patientSinedria()->max('sinedriadate');

		return view('patients.createSinedria', compact('patient', 'listpresenting_complaint', 'listclinical_otoscopy', 'listclinical_endoscopy', 'listclinical_neurotology', 'listclinical_neck', 'listdiagnosis', 'listtreatment', 'listrecipe', 'rinneList', 'weberList', 'tympList', 'tonsilList', 'malapantiList', 'evidenceList', 'priorityList', 'check_surgeryList', 'listclinical_pta', 'listclinical_oral_cavity', 'lastsinedria', 'stopBangList', 'mullerglossaList', 'mulleryperoaList'));
    }

	public function  storeSinedria(Request $request)
    {
        
		$patientSinedria = $request->all();
		$newSinedria = Sinedria::create($patientSinedria); 
		if (!is_null($patientSinedria['clinical_pta'])) {$firstname = Katigories::firstOrCreate(['onomasia' => $patientSinedria['clinical_pta']], ['id_katigoria'=>213]);} 
		if (!is_null($patientSinedria['clinical_oral_cavity'])) {$firstname = Katigories::firstOrCreate(['onomasia' => $patientSinedria['clinical_oral_cavity']], ['id_katigoria'=>214]);} 

		return redirect('patients/detailSinedria/'.$request->patient_id)->with('success','Item created successfully! ');

    }

    public function editSinedria($id)
    {
        $patientSinedria = Sinedria::find($id);
		$listpresenting_complaint = Katigories::where('id_katigoria', 201) //�� listxxxx ������� �� autocomplete, ��� �� xxxxlist ������� select 
			->orderBy('onomasia')->pluck('onomasia', 'onomasia'); 
		$listclinical_otoscopy = Katigories::where('id_katigoria', 211)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listclinical_endoscopy = Katigories::where('id_katigoria', 208)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listclinical_neurotology = Katigories::where('id_katigoria', 212)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listclinical_neck = Katigories::where('id_katigoria', 209)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listdiagnosis = Katigories::where('id_katigoria', 202)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listtreatment = Katigories::where('id_katigoria', 203)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$listrecipe = Katigories::where('id_katigoria', 220)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$rinneList = Katigories::where('id_katigoria', 204)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$weberList = Katigories::where('id_katigoria', 205)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$tympList = Katigories::where('id_katigoria', 206)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$tonsilList = Katigories::where('id_katigoria', 207)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$malapantiList = Katigories::where('id_katigoria', 210)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$evidenceList = Katigories::where('id_katigoria', 221)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$priorityList = Katigories::where('id_katigoria', 200)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$check_surgeryList = Katigories::where('id_katigoria', 215)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$stopBangList = Katigories::where('id_katigoria', 222)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$mullerglossaList = Katigories::where('id_katigoria', 223)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');	
		$mulleryperoaList = Katigories::where('id_katigoria', 224)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');		

		return view('patients.editSinedria', compact('patientSinedria', 'listpresenting_complaint', 'listclinical_otoscopy', 'listclinical_endoscopy', 'listclinical_neurotology', 'listclinical_neck', 'listdiagnosis', 'listtreatment', 'listrecipe', 'rinneList', 'weberList', 'tympList', 'tonsilList', 'malapantiList', 'evidenceList', 'priorityList', 'check_surgeryList', 'stopBangList', 'mullerglossaList', 'mulleryperoaList')); 
    }

    public function updateSinedria(Request $request, $id)
    {
        $sinedriaUpdate = $request->all();
		$patientSinedria = Sinedria::find($id);
		$patientSinedria->update($sinedriaUpdate);
		return redirect('patients/show/'.$patientSinedria->patient_id); 
    }

    public function destroySinedria($id, $patient_id)
    {
        $sinedria = Sinedria::find($id)->delete();
	//	return redirect('patients/show/'.$patient_id); 
    }

    public function printSinedria($id, $patient_id)
    {

        $patient = Patient::find($patient_id);  
        $sinedria = Sinedria::find($id);  

		$pdf = PDF::loadView('patients.sinedriaForm', compact('patient', 'sinedria'));
		$pdf->setPaper('A4', 'portrait');
//		return $pdf->download('report-'.$patient->lastname.'.pdf');	
//		return $pdf->stream("filename.pdf", array("Attachment" => false));
		$match_files = File::glob('document*');
		if($match_files !== false) {
			foreach($match_files as $file) {
			if(file_exists($file))
			File::delete($file);
			}
		}
		$output = $pdf->output();
		$newfile = 'document'.strval(rand(0, 9999999)).'.pdf';
		file_put_contents($newfile, $output);
		echo $newfile;


    }

    public function printRecipe($id, $patient_id)
    {

        $patient = Patient::find($patient_id);  
        $sinedria = Sinedria::find($id);  

		$pdf = PDF::loadView('patients.recipeForm', compact('patient', 'sinedria'));
		$pdf->setPaper('A5', 'portrait');
//		return $pdf->download('recipe-'.$patient->lastname.'.pdf');	
//		return $pdf->stream("filename.pdf", array("Attachment" => false));
		$match_files = File::glob('document*');
		if($match_files !== false) {
			foreach($match_files as $file) {
			if(file_exists($file))
			File::delete($file);
			}
		}
		$output = $pdf->output();
		$newfile = 'document'.strval(rand(0, 9999990)).'.pdf';
		file_put_contents($newfile, $output);
		echo $newfile;
    }

    public function createReminder($id)
    {
        $patient = Patient::find($id);
		$max = Sinedria::where('patient_id', $id)->max('id');
		$sinedria = Sinedria::find($max);
		$listdescription = Katigories::where('id_katigoria', 301) //�� listxxxx ������� �� autocomplete, ��� �� xxxxlist ������� select 
			->orderBy('onomasia')->pluck('onomasia', 'onomasia'); 
		

		return view('patients.createReminder', compact('patient', 'listdescription', 'sinedria'));
    }

	public function  storeReminder(Request $request)
    {
        
        $patientReminder = $request->all();
		Reminder::create($patientReminder);        
		return redirect('patients/show/'.$request->patient_id);
    }


    public function editReminder($id)
    {
		$patientReminder = Reminder::find($id);
		$patient = Patient::find($patientReminder->patient_id);
		$max = Sinedria::where('patient_id', $patient->id)->max('id');
		$sinedria = Sinedria::find($max);
		$listdescription = Katigories::where('id_katigoria', 301) //�� listxxxx ������� �� autocomplete, ��� �� xxxxlist ������� select 
			->orderBy('onomasia')->pluck('onomasia', 'onomasia'); 

		return view('patients.editReminder', compact('patientReminder', 'listdescription', 'sinedria', 'patient')); 
    }

    public function updateReminder(Request $request, $id)
    {
        $reminderUpdate = $request->all();
		$patientReminder = Reminder::find($id);
		$patientReminder->update($reminderUpdate);
		return redirect('patients/show/'.$patientReminder->patient_id); 
    }

	public function addWaiting($id)
    {
		$waiting = WaitingList::firstOrNew(['patient_id' => $id, 'dateadded' => date("Y-m-d")]);
		$waiting->completed = 'NO';
		$ctWaiting = WaitingList::where('dateadded', date("Y-m-d"))->max('ordering');
		$waiting->ordering = $ctWaiting+1;
		$waiting->save();



		return redirect('patients');
    }

    public function destroyReminder($id, $patient_id)
    {
        $reminder = Reminder::find($id)->delete();
		return redirect('patients/show/'.$patient_id); 
    }


}
